#
# Conditional build:
%bcond_without	python2	# CPython 2.x module
%bcond_with	python3	# CPython 3.x module (built from python3-pexpect.spec)
%bcond_with	tests	# py.test tests [require ptys, so not on builders]
%bcond_without	doc	# Sphinx documentation

%define		module	pexpect
Summary:	Pure Python Expect-like module
Summary(pl.UTF-8):	Moduł podobny do narzędzia Expect napisany w czystym Pythonie
Name:		python-%{module}
# keep 4.8.x here for working python2 support
# (even though 4.9.0 isn't marked as python3-only, but tests are incompatbible
#  with python2, new socket_pexpect module is python3-specific etc.)
Version:	4.8.0
Release:	10
License:	ISC
Group:		Development/Languages/Python
#Source0Download: https://pypi.org/simple/pexpect/
Source0:	https://files.pythonhosted.org/packages/source/p/pexpect/pexpect-%{version}.tar.gz
# Source0-md5:	153eb25184249d6a85fde9acf4804085
Patch0:		%{name}-use_setuptools.patch
Patch1:		sphinx-api.patch
URL:		https://pexpect.readthedocs.io/
%if %{with tests} && %(locale -a | grep -q '^C\.utf8$'; echo $?)
BuildRequires:	glibc-localedb-all
%endif
%if %{with python2}
BuildRequires:	python-devel >= 1:2.7
BuildRequires:	python-modules >= 1:2.7
BuildRequires:	python-setuptools
%if %{with tests}
BuildRequires:	python-ptyprocess >= 0.5
BuildRequires:	python-pytest
%endif
%endif
%if %{with python3}
BuildRequires:	python3-modules >= 1:3.2
BuildRequires:	python3-setuptools
%if %{with tests}
BuildRequires:	python3-ptyprocess >= 0.5
BuildRequires:	python3-pytest
%endif
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with doc}
BuildRequires:	sphinx-pdg-2
%endif
Requires:	python-modules >= 1:2.7
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Pexpect is a pure Python module for spawning child applications;
controlling them; and responding to expected patterns in their output.
Pexpect works like Don Libes' Expect. Pexpect allows your script to
spawn a child application and control it as if a human were typing
commands.

%description -l pl.UTF-8
Pexpect jest modułem napisanym wyłącznie w Pythonie przeznaczonym do
uruchamiania aplikacji i kontroli nad nimi poprzez reagowanie na
znalezione wzorce na ich wyjściu. Pexpect działa podobnie do Expecta
Dona Libesa - pozwala skryptom z ich poziomu uruchomić inne programy i
sprawować nad nimi kontrolę imitując interakcję użytkownika.

%package -n python3-%{module}
Summary:	Pure Python Expect-like module
Summary(pl.UTF-8):	Moduł podobny do narzędzia Expect napisany w czystym Pythonie
Group:		Development/Languages/Python
Requires:	python3-modules >= 1:3.2

%description -n python3-%{module}
Pexpect is a pure Python module for spawning child applications;
controlling them; and responding to expected patterns in their output.
Pexpect works like Don Libes' Expect. Pexpect allows your script to
spawn a child application and control it as if a human were typing
commands.

%description -n python3-%{module} -l pl.UTF-8
Pexpect jest modułem napisanym wyłącznie w Pythonie przeznaczonym do
uruchamiania aplikacji i kontroli nad nimi poprzez reagowanie na
znalezione wzorce na ich wyjściu. Pexpect działa podobnie do Expecta
Dona Libesa - pozwala skryptom z ich poziomu uruchomić inne programy i
sprawować nad nimi kontrolę imitując interakcję użytkownika.

%package apidocs
Summary:	Documentation for Python pexpect module
Summary(pl.UTF-8):	Dokumentacja do modułu Pythona pexpect
Group:		Documentation

%description apidocs
Documentation for Python pexpect module.

%description apidocs -l pl.UTF-8
Dokumentacja do modułu Pythona pexpect.

%prep
%setup -q -n %{module}-%{version}
%patch -P 0 -p1
%patch -P 1 -p1

# fix invalid mapping
sed -i -e "s#^intersphinx_mapping =.*#intersphinx_mapping = {'python': ('https://docs.python.org/3', None)}#g" doc/conf.py

%build
%if %{with python2}
%py_build

%if %{with tests}
# FSM test fails with python 2 because of redirected output(?)
LC_ALL=C.UTF-8 \
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
%{__python} -m pytest -k 'not test_run_fsm' tests
%endif
%endif

%if %{with python3}
%py3_build

%if %{with tests}
LC_ALL=C.UTF-8 \
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
%{__python3} -m pytest tests
%endif
%endif

%if %{with doc}
%{__make} -C doc html \
	SPHINXBUILD=sphinx-build-2
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%py_install

%py_postclean

%{__rm} $RPM_BUILD_ROOT%{py_sitescriptdir}/pexpect/bashrc.sh

install -d $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
cp -p examples/* $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
%{__sed} -i -e '1s,/usr/bin/env python,%{__python},' $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}/*.py
%{__sed} -i -e '1s,/usr/bin/python,%{__python},' $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}/cgishell.cgi
%{__sed} -i -e '2s,/usr/bin/env python,,' $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}/cgishell.cgi
%endif

%if %{with python3}
%py3_install

%{__rm} $RPM_BUILD_ROOT%{py3_sitescriptdir}/pexpect/bashrc.sh

install -d $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}
cp -p examples/* $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}
%{__sed} -i -e '1s,/usr/bin/env python,%{__python3},' $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}/*.py
%{__sed} -i -e '1s,/usr/bin/python,%{__python3},' $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}/cgishell.cgi
%{__sed} -i -e '2s,/usr/bin/env python,,' $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}/cgishell.cgi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc LICENSE README.rst
%{py_sitescriptdir}/pexpect
%{py_sitescriptdir}/pexpect-%{version}-py*.egg-info
%{_examplesdir}/%{name}-%{version}
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%doc LICENSE README.rst
%{py3_sitescriptdir}/pexpect
%{py3_sitescriptdir}/pexpect-%{version}-py*.egg-info
%{_examplesdir}/python3-%{module}-%{version}
%endif

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc doc/_build/html/{_static,api,*.html,*.js}
%endif
%changelog
* Sat Jun 28 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-pexpect.git;a=log;h=master

* Sat Jun 28 2025 Jakub Bogusz <qboosh@pld-linux.org> 3a389e9
- disable python3 here, switched docs to python2; release 10

* Mon Mar 17 2025 Arkadiusz Miśkiewicz <arekm@maven.pl> 4d982cf
- Rel 9; fix invalid mapping at docs build

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> a15bb04
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> b6b51c2
- python 3.13 rebuild

* Sun Mar 09 2025 Jan Rękorajski <baggins@pld-linux.org> 650c325
- use patch -P

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> b716738
- rebuild with tests and docs

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> a68044e
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> d8d4f74
- rebuild with python 3.10

* Tue Mar 02 2021 Jan Rękorajski <baggins@pld-linux.org> bf331c3
- remove incorrect and useless sphinx call
- rel 3

* Sat Feb 01 2020 Jakub Bogusz <qboosh@pld-linux.org> cd1b1f5
- python3 shebang fixes fix

* Sat Feb 01 2020 Jakub Bogusz <qboosh@pld-linux.org> 88d6cbd
- fix examples shebangs; release 2

* Fri Jan 31 2020 Jakub Bogusz <qboosh@pld-linux.org> 99b610e
- updated to 4.8.0
- added use_setuptools patch (always use setuptools so that pythonegg deps are autogenerated)

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> b629dd7
- rebuild with python 3.8
- release 2 (by relup.sh)

* Sun Sep 22 2019 Jakub Bogusz <qboosh@pld-linux.org> fc46937
- updated to 4.7.0
- removed obsolete tests patch

* Sat Aug 31 2019 Jan Rękorajski <baggins@pld-linux.org> 64cfd3c
- fix deps
- rel 2

* Wed Aug 01 2018 Jakub Bogusz <qboosh@pld-linux.org> 4403ea8
- updated to 4.6.0
- added tests patch (fix one failure due to openssl pipe error message)

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 1bbb54d
- release 3 (by relup.sh)

* Mon Mar 27 2017 Mateusz Korniak <matkor@pld-linux.org> 1d06149
- release 2

* Sun Mar 12 2017 Jakub Bogusz <qboosh@pld-linux.org> 31581d0
- disable tests by default due to pty usage

* Sun Mar 12 2017 Jakub Bogusz <qboosh@pld-linux.org> e0a16c9
- updated to 4.2.1
- added python3- and -apidocs packages

